@@ -8,6 +8,11 @@ from django_browserid import helpers
 register = template.Library()
 
 
+@fancy_tag(register, takes_context=True)
+def browserid_info(context, **kwargs):
+    return helpers.browserid_info(**kwargs)
+
+
 @fancy_tag(register, takes_context=True)
 def browserid_login(context, **kwargs):
     return helpers.browserid_login(**kwargs)
