@@ -26,5 +26,5 @@ except ImproperlyConfigured as e:
 urlpatterns = patterns('',
     url(r'^browserid/login/$', Verify.as_view(), name='browserid.login'),
     url(r'^browserid/logout/$', views.Logout.as_view(), name='browserid.logout'),
-    url(r'^browserid/info/$', views.Info.as_view(), name='browserid.info'),
+    url(r'^browserid/csrf/$', views.CsrfToken.as_view(), name='browserid.csrf'),
 )
